summaryrefslogtreecommitdiff
path: root/board/taeko/fw_config.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/taeko/fw_config.c')
-rw-r--r--board/taeko/fw_config.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/board/taeko/fw_config.c b/board/taeko/fw_config.c
index fb8acb635d..886c56b314 100644
--- a/board/taeko/fw_config.c
+++ b/board/taeko/fw_config.c
@@ -11,20 +11,20 @@
#define CPRINTS(format, args...) cprints(CC_CHIPSET, format, ## args)
-static union brya_cbi_fw_config fw_config;
+static union taeko_cbi_fw_config fw_config;
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
* FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
* initialized.
*/
-static const union brya_cbi_fw_config fw_config_defaults = {
+static const union taeko_cbi_fw_config fw_config_defaults = {
.usb_db = DB_USB3_PS8815,
.kb_bl = KEYBOARD_BACKLIGHT_ENABLED,
};
/****************************************************************************
- * Brya FW_CONFIG access
+ * Taeko FW_CONFIG access
*/
void board_init_fw_config(void)
{
@@ -49,7 +49,7 @@ void board_init_fw_config(void)
}
}
-union brya_cbi_fw_config get_fw_config(void)
+union taeko_cbi_fw_config get_fw_config(void)
{
return fw_config;
}
@@ -11,20 +11,20 @@
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
- * FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
+ * FW_CONFIG defaults for Taeko if the CBI.FW_CONFIG data is not
* initialized.
*/